@@ -6,32 +6,35 @@ from datetime import timedelta
 from datetime import timezone
 from http import HTTPStatus
 
+from ..datastructures import CallbackDict
+from ..datastructures import ContentRange
+from ..datastructures import ContentSecurityPolicy
 from ..datastructures import Headers
 from ..datastructures import HeaderSet
+from ..datastructures import ResponseCacheControl
+from ..datastructures import WWWAuthenticate
+from ..http import COEP
+from ..http import COOP
+from ..http import dump_age
 from ..http import dump_cookie
+from ..http import dump_header
+from ..http import dump_options_header
+from ..http import http_date
 from ..http import HTTP_STATUS_CODES
+from ..http import parse_age
+from ..http import parse_cache_control_header
+from ..http import parse_content_range_header
+from ..http import parse_csp_header
+from ..http import parse_date
+from ..http import parse_options_header
+from ..http import parse_set_header
+from ..http import quote_etag
+from ..http import unquote_etag
 from ..utils import get_content_type
-from werkzeug.datastructures import CallbackDict
-from werkzeug.datastructures import ContentRange
-from werkzeug.datastructures import ContentSecurityPolicy
-from werkzeug.datastructures import ResponseCacheControl
-from werkzeug.datastructures import WWWAuthenticate
-from werkzeug.http import COEP
-from werkzeug.http import COOP
-from werkzeug.http import dump_age
-from werkzeug.http import dump_header
-from werkzeug.http import dump_options_header
-from werkzeug.http import http_date
-from werkzeug.http import parse_age
-from werkzeug.http import parse_cache_control_header
-from werkzeug.http import parse_content_range_header
-from werkzeug.http import parse_csp_header
-from werkzeug.http import parse_date
-from werkzeug.http import parse_options_header
-from werkzeug.http import parse_set_header
-from werkzeug.http import quote_etag
-from werkzeug.http import unquote_etag
-from werkzeug.utils import header_property
+from ..utils import header_property
+
+if t.TYPE_CHECKING:
+    from ..datastructures.cache_control import _CacheControl
 
 
 def _set_property(name: str, doc: str | None = None) -> property:
@@ -131,7 +134,7 @@ class Response:
             self.headers["Content-Type"] = content_type
         if status is None:
             status = self.default_status
-        self.status = status  # type: ignore
+        self.status = status
 
     def __repr__(self) -> str:
         return f"<{type(self).__name__} [{self.status}]>"
@@ -143,7 +146,7 @@ class Response:
 
     @status_code.setter
     def status_code(self, code: int) -> None:
-        self.status = code  # type: ignore
+        self.status = code
 
     @property
     def status(self) -> str:
@@ -194,6 +197,7 @@ class Response:
         secure: bool = False,
         httponly: bool = False,
         samesite: str | None = None,
+        partitioned: bool = False,
     ) -> None:
         """Sets a cookie.
 
@@ -218,6 +222,10 @@ class Response:
         :param httponly: Disallow JavaScript access to the cookie.
         :param samesite: Limit the scope of the cookie to only be
             attached to requests that are "same-site".
+        :param partitioned: If ``True``, the cookie will be partitioned.
+
+        .. versionchanged:: 3.1
+            The ``partitioned`` parameter was added.
         """
         self.headers.add(
             "Set-Cookie",
@@ -232,6 +240,7 @@ class Response:
                 httponly=httponly,
                 max_size=self.max_cookie_size,
                 samesite=samesite,
+                partitioned=partitioned,
             ),
         )
 
@@ -243,6 +252,7 @@ class Response:
         secure: bool = False,
         httponly: bool = False,
         samesite: str | None = None,
+        partitioned: bool = False,
     ) -> None:
         """Delete a cookie.  Fails silently if key doesn't exist.
 
@@ -256,6 +266,7 @@ class Response:
         :param httponly: Disallow JavaScript access to the cookie.
         :param samesite: Limit the scope of the cookie to only be
             attached to requests that are "same-site".
+        :param partitioned: If ``True``, the cookie will be partitioned.
         """
         self.set_cookie(
             key,
@@ -266,6 +277,7 @@ class Response:
             secure=secure,
             httponly=httponly,
             samesite=samesite,
+            partitioned=partitioned,
         )
 
     @property
@@ -305,7 +317,7 @@ class Response:
         .. versionadded:: 0.5
         """
 
-        def on_update(d: CallbackDict) -> None:
+        def on_update(d: CallbackDict[str, str]) -> None:
             self.headers["Content-Type"] = dump_options_header(self.mimetype, d)
 
         d = parse_options_header(self.headers.get("content-type", ""))[1]
@@ -480,7 +492,7 @@ class Response:
         request/response chain.
         """
 
-        def on_update(cache_control: ResponseCacheControl) -> None:
+        def on_update(cache_control: _CacheControl) -> None:
             if not cache_control and "cache-control" in self.headers:
                 del self.headers["cache-control"]
             elif cache_control:
